# django-admin-honeypot

django-admin-honeypot is a fake Django admin login screen to notify admins of attempted unauthorized access. This app was inspired by discussion in and around Paul McMillan's security talk at DjangoCon 2011.

* **Author**: [Derek Payton](http://dmpayton.com)
* **Version**: 0.2.0
* **License**: MIT

## Installation

django-admin-honeypot can be installed in any number of the usual ways:

```
easy_install django-admin-honeypot
```

```
pip install django-admin-honeypot
```

```
pip install -e git+git://github.com/dmpayton/django-admin-honeypot.git#egg=django-admin-honeypot
```

```
git clone git://github.com/dmpayton/django-admin-honeypot.git
cd django-admin-honeypot
python setup.py install
```

etc...

## Usage

* Add `admin_honeypot` to `INSTALLED_APPS`.
* Update your urls.py:

    ```
    urlpatterns = patterns(''
        ...
        url(r'^admin/', include('admin_honeypot.urls')),
        url(r'^secret/', include(admin.site.urls)),
    )
    ```

## Settings

**ADMIN\_HONEYPOT\_EMAIL\_ADMINS**  
Set to False to disable admin emails on login attempt  
***Default:** True*

## Signals

`admin_honeypot.signals.honeypot` is called on every login attempt with the following arguments:

* **instance**: The LoginAttempt object created
* **request**: The current request object

## Testing

    python manage.py test admin_honeypot
